@@ -23,6 +23,9 @@
 #include <algorithm>
 #include <glibmm/i18n.h>
 
+namespace Glom
+{
+
 Box_DB_Table_Relationships::Box_DB_Table_Relationships()
 {
   init();
@@ -64,16 +67,20 @@ Box_DB_Table_Relationships::~Box_DB_Table_Relationships()
 
 bool Box_DB_Table_Relationships::fill_from_database()
 {
-  Bakery::BusyCursor(*get_app_window());
+  Bakery::BusyCursor busy_cursor(get_app_window());
 
   bool result = Box_DB_Table::fill_from_database();
 
+  Document_Glom* document = get_document();
+  if(!document)
+    return false;
+
   //Get relationships from the document:
-  Document_Glom::type_vecRelationships vecRelationships = get_document()->get_relationships(m_table_name);
+  Document_Glom::type_vecRelationships vecRelationships = document->get_relationships(m_table_name);
 
   m_AddDel.remove_all();
 
-  sharedptr<SharedConnection> sharedconnection = connect_to_server();
+  sharedptr<SharedConnection> sharedconnection = connect_to_server(get_app_window());
   if(sharedconnection)
   {
     Glib::RefPtr<Gnome::Gda::Connection> connection = sharedconnection->get_gda_connection();
@@ -81,7 +88,7 @@ bool Box_DB_Table_Relationships::fill_from_database()
     //Set combo choices:
     m_AddDel.set_column_choices(m_colFromField, util_vecStrings_from_Fields(get_fields_for_table(m_table_name)));
 
-    type_vecStrings vecTableNames = get_table_names(true /* ignore_system_tables */);
+    type_vecStrings vecTableNames = document->get_table_names(false /* ignore_system_tables */);
     type_vecStrings vecTableNames_ustring(vecTableNames.begin(), vecTableNames.end());
     m_AddDel.set_column_choices(m_colToTable, vecTableNames_ustring);
 
@@ -181,7 +188,7 @@ void Box_DB_Table_Relationships::on_adddel_user_added(const Gtk::TreeModel::iter
     Glib::ustring title = m_AddDel.get_value(row, m_colTitle);
     if(title.empty())
     {
-      title = Base_DB::util_title_from_string(new_name);
+      title = Utils::title_from_string(new_name);
       m_AddDel.set_value(row, m_colTitle, title);
     }
   }
@@ -200,7 +207,7 @@ void Box_DB_Table_Relationships::on_adddel_user_changed(const Gtk::TreeModel::it
     Glib::ustring title = m_AddDel.get_value(row, m_colTitle);
     if(title.empty())
     {
-      title = Base_DB::util_title_from_string(new_name);
+      title = Utils::title_from_string(new_name);
       m_AddDel.set_value(row, m_colTitle, title);
     }
   }
@@ -218,7 +225,7 @@ void Box_DB_Table_Relationships::on_adddel_user_activated(const Gtk::TreeModel::
 {
   if(col == m_colToField)
   {
-    Bakery::BusyCursor(*get_app_window());
+    Bakery::BusyCursor busy_cursor(get_app_window());
 
     const Glib::ustring old_to_field = m_AddDel.get_value(row, m_colToField);
 
@@ -229,7 +236,7 @@ void Box_DB_Table_Relationships::on_adddel_user_activated(const Gtk::TreeModel::
       //Set list of 'To' fields depending on table:
       m_AddDel.set_value(row, m_colToField, Glib::ustring(""));
 
-      sharedptr<SharedConnection> sharedconnection = connect_to_server();
+      sharedptr<SharedConnection> sharedconnection = connect_to_server(get_app_window());
       if(sharedconnection)
       {
         Glib::RefPtr<Gnome::Gda::Connection> connection = sharedconnection->get_gda_connection();
@@ -277,3 +284,5 @@ void Box_DB_Table_Relationships::on_adddel_user_requested_delete(const Gtk::Tree
 
   set_modified();
 }
+
+} //namespace Glom
